import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { CartService } from '../service/Cart.service';
import {
  CDTO_Cart,
  CVO_Cart,
  FVO_Cart,
  QDTO_Cart,
  QVO_Cart,
  UDTO_Cart,
  UVAO_Cart,
} from '../interface/Cart.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['购物车'])
@Controller('/Cart')
export class CartController extends BaseController {
  @Inject()
  service: CartService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_Cart })
  async create(@Body() data: CDTO_Cart) {
    const dbData = await this.service.specialCreate(data);
    const result = new CVO_Cart(dbData);
    return result;
  }
  @Post('/checkCartBuy')
  async checkCartBuy(@Body() data: any) {
    const result = await this.service.checkCartBuy(data);
    return result;
  }

  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_Cart })
  async query(
    @Query() filter: QDTO_Cart,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_Cart(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }
  @Get('/self')
  async self(@Query('user') user: string) {
    const list = await this.service.self(user);
    return list;
  }
  @Get('/num')
  async num(@Query('user') user: string) {
    const result = await this.service.num(user);
    return result;
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_Cart })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_Cart(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_Cart })
  async update(@Param('id') id: string, @Body() body: UDTO_Cart) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/deleteMany')
  @Validate()
  async deleteSome(@Body() data: any) {
    const result = await this.service.deleteSome(data);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
