import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ConfigService } from '../service/Config.service';
import {
  CDTO_Config,
  CVO_Config,
  FVO_Config,
  QVO_Config,
  UDTO_Config,
  UVAO_Config,
} from '../interface/Config.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['基础设置表'])
@Controller('/Config')
export class ConfigController extends BaseController {
  @Inject()
  service: ConfigService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_Config })
  async create(@Body() data: CDTO_Config) {
    const dbData = await this.service.create(data);
    const result = new CVO_Config(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_Config })
  async query() {
    const data = await this.service.findByOne();
    const result = new QVO_Config(data);
    return result;
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_Config })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_Config(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_Config })
  async update(@Param('id') id: string, @Body() body: UDTO_Config) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
