import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DictDataService } from '../service/DictData.service';
import {
  CDTO_DictData,
  CVO_DictData,
  FVO_DictData,
  QDTO_DictData,
  QVO_DictData,
  UDTO_DictData,
  UVAO_DictData,
} from '../interface/DictData.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['字典数据'])
@Controller('/DictData')
export class DictDataController extends BaseController {
  @Inject()
  service: DictDataService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_DictData })
  async create(@Body() data: CDTO_DictData) {
    const dbData = await this.service.create(data);
    const result = new CVO_DictData(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_DictData })
  async query(
    @Query() filter: QDTO_DictData,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_DictData(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_DictData })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_DictData(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_DictData })
  async update(@Param('id') id: string, @Body() body: UDTO_DictData) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
