import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DictTypeService } from '../service/DictType.service';
import {
  CDTO_DictType,
  CVO_DictType,
  FVO_DictType,
  QDTO_DictType,
  QVO_DictType,
  UDTO_DictType,
  UVAO_DictType,
} from '../interface/DictType.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['字典类型'])
@Controller('/DictType')
export class DictTypeController extends BaseController {
  @Inject()
  service: DictTypeService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_DictType })
  async create(@Body() data: CDTO_DictType) {
    const dbData = await this.service.create(data);
    const result = new CVO_DictType(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_DictType })
  async query(
    @Query() filter: QDTO_DictType,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_DictType(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_DictType })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_DictType(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_DictType })
  async update(@Param('id') id: string, @Body() body: UDTO_DictType) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
