import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { OfficeService } from '../service/Office.service';
import {
  CDTO_Office,
  CVO_Office,
  FVO_Office,
  QDTO_Office,
  QVO_Office,
  UDTO_Office,
  UVAO_Office,
} from '../interface/Office.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['街道和社区'])
@Controller('/Office')
export class OfficeController extends BaseController {
  @Inject()
  service: OfficeService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_Office })
  async create(@Body() data: CDTO_Office) {
    const dbData = await this.service.create(data);
    const result = new CVO_Office(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_Office })
  async query(
    @Query() filter: QDTO_Office,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_Office(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_Office })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_Office(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_Office })
  async update(@Param('id') id: string, @Body() body: UDTO_Office) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
