import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { OrderService } from '../service/Order.service';
import {
  CDTO_Order,
  CVO_Order,
  FVO_Order,
  QDTO_Order,
  QVO_Order,
  UDTO_Order,
  UVAO_Order,
} from '../interface/Order.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['订单'])
@Controller('/Order')
export class OrderController extends BaseController {
  @Inject()
  service: OrderService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_Order })
  async create(@Body() data: CDTO_Order) {
    const dbData = await this.service.create(data);
    const result = new CVO_Order(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_Order })
  async query(
    @Query() filter: QDTO_Order,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_Order(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_Order })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_Order(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_Order })
  async update(@Param('id') id: string, @Body() body: UDTO_Order) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
