import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { OrderDetailService } from '../service/OrderDetail.service';
import {
  CDTO_OrderDetail,
  CVO_OrderDetail,
  FVO_OrderDetail,
  QDTO_OrderDetail,
  QVO_OrderDetail,
  // UDTO_OrderDetail,
  UVAO_OrderDetail,
} from '../interface/OrderDetail.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['订单详情'])
@Controller('/OrderDetail')
export class OrderDetailController extends BaseController {
  @Inject()
  service: OrderDetailService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_OrderDetail })
  async create(@Body() data: CDTO_OrderDetail) {
    const dbData = await this.service.create(data);
    const result = new CVO_OrderDetail(dbData);
    return result;
  }

  @Get('/queryInfo')
  @ApiQuery({ name: 'queryInfo' })
  async queryInfo(@Query() filter: any) {
    const list: any = await this.service.queryInfo(filter);
    const data = list.list;
    const total = list.total;
    return { data, total };
  }

  @Get('/money')
  @ApiQuery({ name: 'money' })
  async money(@Query() filter: any) {
    const list: any = await this.service.money(filter);
    const data = list.list;
    const total = list.total;
    return { data, total };
  }

  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_OrderDetail })
  async query(
    @Query() filter: QDTO_OrderDetail,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_OrderDetail(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/detail/:id')
  async detail(@Param('id') id: string) {
    const data = await this.service.detail(id);
    return data;
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_OrderDetail })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_OrderDetail(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_OrderDetail })
  async update(@Param('id') id: string, @Body() body: any) {
    const result = await this.service.update(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
