import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { RoleService } from '../service/Role.service';
import {
  CDTO_Role,
  CVO_Role,
  FVO_Role,
  QDTO_Role,
  QVO_Role,
  UDTO_Role,
  UVAO_Role,
} from '../interface/Role.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['角色'])
@Controller('/Role')
export class RoleController extends BaseController {
  @Inject()
  service: RoleService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_Role })
  async create(@Body() data: CDTO_Role) {
    const dbData = await this.service.create(data);
    const result = new CVO_Role(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_Role })
  async query(
    @Query() filter: QDTO_Role,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_Role(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/menu')
  @ApiResponse({ type: FVO_Role })
  async menu(@Query('is_use') is_use: string, @Query('code') code: string) {
    const data = await this.service.menu(is_use, code);
    const result = new FVO_Role(data);
    return result;
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_Role })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_Role(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_Role })
  async update(@Param('id') id: string, @Body() body: UDTO_Role) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
