import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ShopSettingService } from '../service/ShopSetting.service';
import {
  CDTO_ShopSetting,
  CVO_ShopSetting,
  FVO_ShopSetting,
  QDTO_ShopSetting,
  QVO_ShopSetting,
  UDTO_ShopSetting,
  UVAO_ShopSetting,
} from '../interface/ShopSetting.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { UserUtilService } from '../service/util/user.util';
@ApiTags(['采购审批设置'])
@Controller('/ShopSetting')
export class ShopSettingController extends BaseController {
  @Inject()
  service: ShopSettingService;

  @Inject()
  userUtil: UserUtilService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_ShopSetting })
  async create(@Body() data: CDTO_ShopSetting) {
    await this.userUtil.checkOffice(data);
    // 检查街道/社区
    const dbData = await this.service.create(data);
    const result = new CVO_ShopSetting(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_ShopSetting })
  async query(
    @Query() filter: QDTO_ShopSetting,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_ShopSetting(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_ShopSetting })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_ShopSetting(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_ShopSetting })
  async update(@Param('id') id: string, @Body() body: UDTO_ShopSetting) {
    // 检查街道/社区
    await this.userUtil.checkUpdateOffice(id, body);
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
