import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { SpecsService } from '../service/Specs.service';
import {
  CDTO_Specs,
  CVO_Specs,
  FVO_Specs,
  QDTO_Specs,
  QVO_Specs,
  UDTO_Specs,
  UVAO_Specs,
} from '../interface/Specs.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['商品规格'])
@Controller('/Specs')
export class SpecsController extends BaseController {
  @Inject()
  service: SpecsService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_Specs })
  async create(@Body() data: CDTO_Specs) {
    const dbData = await this.service.create(data);
    const result = new CVO_Specs(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_Specs })
  async query(
    @Query() filter: QDTO_Specs,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_Specs(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_Specs })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_Specs(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_Specs })
  async update(@Param('id') id: string, @Body() body: UDTO_Specs) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
