import { Rule, RuleType } from '@midwayjs/validate';
import { ApiProperty } from '@midwayjs/swagger';
import {
  FrameworkErrorEnum,
  SearchBase,
  ServiceError,
} from 'free-midway-component';
import get = require('lodash/get');
const dealVO = (cla, data) => {
  for (const key in cla) {
    const val = get(data, key);
    if (val || val === 0) cla[key] = val;
  }
};
export class FVO_Admin {
  constructor(data: object) {
    dealVO(this, data);
  }
  @ApiProperty({ description: '数据id' })
  _id: string = undefined;
  @ApiProperty({ description: '口令' })
  'username': string = undefined;
  @ApiProperty({ description: '密码' })
  'password': string = undefined;
  @ApiProperty({ description: '显示名' })
  'name': string = undefined;
}

export class QDTO_Admin extends SearchBase {
  constructor() {
    const like_prop = [];
    const props = ['username'];
    const mapping = [];
    super({ like_prop, props, mapping });
  }
  @ApiProperty({ description: '口令' })
  'username': string = undefined;
}

export class QVO_Admin extends FVO_Admin {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class CDTO_Admin {
  @ApiProperty({ description: '口令' })
  @Rule(
    RuleType['string']()
      .required()
      .error(new ServiceError('缺少口令', FrameworkErrorEnum.NEED_BODY))
  )
  'username': string = undefined;
  @ApiProperty({ description: '密码' })
  @Rule(
    RuleType['string']()
      .required()
      .error(new ServiceError('缺少密码', FrameworkErrorEnum.NEED_BODY))
  )
  'password': string = undefined;
  @ApiProperty({ description: '显示名' })
  @Rule(RuleType['string']().empty(''))
  'name': string = undefined;
}

export class CVO_Admin extends FVO_Admin {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class UDTO_Admin extends CDTO_Admin {
  @ApiProperty({ description: '数据id' })
  @Rule(RuleType['string']().empty(''))
  _id: string = undefined;
}

export class UVAO_Admin extends FVO_Admin {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}
export class LoginVO {
  constructor(data: object) {
    for (const key of Object.keys(this)) {
      this[key] = get(data, key);
    }
  }
  @ApiProperty({ description: '数据id' })
  _id: string = undefined;
  @ApiProperty({ description: '口令' })
  'username': string = undefined;
  @ApiProperty({ description: '显示名' })
  'name': string = undefined;
}

export class LoginDTO {
  @ApiProperty({ description: '口令', example: 'admin' })
  @Rule(RuleType['string']().empty(''))
  'username': string = undefined;
  @ApiProperty({ description: '密码', example: '111111' })
  @Rule(RuleType['string']().empty(''))
  'password': string = undefined;
}

export class ResetPasswordDTO {
  @ApiProperty({ description: '用户id', example: '' })
  @Rule(RuleType['string']().required())
  '_id': string = undefined;
  @ApiProperty({ description: '密码', example: '123456' })
  @Rule(RuleType['string']().required())
  'password': string = undefined;
}
