import { Rule, RuleType } from '@midwayjs/validate';
import { ApiProperty } from '@midwayjs/swagger';
import { SearchBase } from 'free-midway-component';
import get = require('lodash/get');
const dealVO = (cla, data) => {
  for (const key in cla) {
    const val = get(data, key);
    if (val || val === 0) cla[key] = val;
  }
};
export class FVO_Good {
  constructor(data: object) {
    dealVO(this, data);
  }
  @ApiProperty({ description: '数据id' })
  _id: string = undefined;
  @ApiProperty({ description: '名称' })
  'name': string = undefined;
  @ApiProperty({ description: '图片' })
  'file': Array<any> = undefined;
  @ApiProperty({ description: '类型' })
  'type': string = undefined;
  @ApiProperty({ description: '简介' })
  'brief': string = undefined;
  @ApiProperty({ description: '销售数量' })
  'sell_num': number = undefined;
  @ApiProperty({ description: '供应商id' })
  'supplier_id': string = undefined;
  @ApiProperty({ description: '是否使用' })
  'is_use': string = undefined;
}

export class QDTO_Good extends SearchBase {
  constructor() {
    const like_prop = ['name'];
    const props = ['_id', 'name', 'type', 'supplier_id', 'is_use'];
    const mapping = [];
    super({ like_prop, props, mapping });
  }
  @ApiProperty({ description: '数据id' })
  _id: string = undefined;
  @ApiProperty({ description: '名称' })
  'name': string = undefined;
  @ApiProperty({ description: '类型' })
  'type': string = undefined;
  @ApiProperty({ description: '供应商id' })
  'supplier_id': string = undefined;
  @ApiProperty({ description: '是否使用' })
  'is_use': string = undefined;
}

export class QVO_Good extends FVO_Good {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class CDTO_Good {
  @ApiProperty({ description: '名称' })
  @Rule(RuleType['string']().empty(''))
  'name': string = undefined;
  @ApiProperty({ description: '图片' })
  @Rule(RuleType['array']().empty(''))
  'file': Array<any> = undefined;
  @ApiProperty({ description: '类型' })
  @Rule(RuleType['string']().empty(''))
  'type': string = undefined;
  @ApiProperty({ description: '简介' })
  @Rule(RuleType['string']().empty(''))
  'brief': string = undefined;
  @ApiProperty({ description: '销售数量' })
  @Rule(RuleType['number']().empty(''))
  'sell_num': number = undefined;
  @ApiProperty({ description: '供应商id' })
  @Rule(RuleType['string']().empty(''))
  'supplier_id': string = undefined;
  @ApiProperty({ description: '是否使用' })
  @Rule(RuleType['string']().empty(''))
  'is_use': string = undefined;
}

export class CVO_Good extends FVO_Good {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class UDTO_Good extends CDTO_Good {
  @ApiProperty({ description: '数据id' })
  @Rule(RuleType['string']().empty(''))
  _id: string = undefined;
}

export class UVAO_Good extends FVO_Good {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}
