import { Rule, RuleType } from '@midwayjs/validate';
import { ApiProperty } from '@midwayjs/swagger';
import {
  FrameworkErrorEnum,
  SearchBase,
  ServiceError,
} from 'free-midway-component';
import get = require('lodash/get');
const dealVO = (cla, data) => {
  for (const key in cla) {
    const val = get(data, key);
    if (val || val === 0) cla[key] = val;
  }
};
export class FVO_ShopSetting {
  constructor(data: object) {
    dealVO(this, data);
  }
  @ApiProperty({ description: '数据id' })
  _id: string = undefined;
  @ApiProperty({ description: '街道/社区' })
  'office': string = undefined;
  @ApiProperty({ description: '领导' })
  'leader': Array<any> = undefined;
  @ApiProperty({ description: '会计' })
  'accounting': Array<any> = undefined;
  @ApiProperty({ description: '是否使用' })
  'is_use': string = undefined;
}

export class QDTO_ShopSetting extends SearchBase {
  constructor() {
    const like_prop = [];
    const props = ['office', 'is_use'];
    const mapping = [];
    super({ like_prop, props, mapping });
  }
  @ApiProperty({ description: '街道/社区' })
  'office': string = undefined;
  @ApiProperty({ description: '是否使用' })
  'is_use': string = undefined;
}

export class QVO_ShopSetting extends FVO_ShopSetting {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class CDTO_ShopSetting {
  @ApiProperty({ description: '街道/社区' })
  @Rule(
    RuleType['string']()
      .required()
      .error(new ServiceError('缺少街道/社区', FrameworkErrorEnum.NEED_BODY))
  )
  'office': string = undefined;
  @ApiProperty({ description: '领导' })
  @Rule(
    RuleType['array']()
      .required()
      .error(new ServiceError('缺少领导', FrameworkErrorEnum.NEED_BODY))
  )
  'leader': Array<any> = undefined;
  @ApiProperty({ description: '会计' })
  @Rule(
    RuleType['array']()
      .required()
      .error(new ServiceError('缺少会计', FrameworkErrorEnum.NEED_BODY))
  )
  'accounting': Array<any> = undefined;
  @ApiProperty({ description: '是否使用' })
  @Rule(RuleType['string']().empty(''))
  'is_use': string = undefined;
}

export class CVO_ShopSetting extends FVO_ShopSetting {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class UDTO_ShopSetting extends CDTO_ShopSetting {
  @ApiProperty({ description: '数据id' })
  @Rule(RuleType['string']().empty(''))
  _id: string = undefined;
}

export class UVAO_ShopSetting extends FVO_ShopSetting {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}
