import { Rule, RuleType } from '@midwayjs/validate';
import { ApiProperty } from '@midwayjs/swagger';
import { SearchBase } from 'free-midway-component';
import get = require('lodash/get');
const dealVO = (cla, data) => {
  for (const key in cla) {
    const val = get(data, key);
    if (val || val === 0) cla[key] = val;
  }
};
export class FVO_Specs {
  constructor(data: object) {
    dealVO(this, data);
  }
  @ApiProperty({ description: '数据id' })
  _id: string = undefined;
  @ApiProperty({ description: '商品源' })
  'goods': string = undefined;
  @ApiProperty({ description: '规格名称' })
  'name': string = undefined;
  @ApiProperty({ description: '销售价格' })
  'money': number = undefined;
  @ApiProperty({ description: '库存' })
  'num': number = undefined;
  @ApiProperty({ description: '状态' })
  'status': string = undefined;
  @ApiProperty({ description: '图片' })
  'file': Array<any> = undefined;
  @ApiProperty({ description: '是否使用' })
  'is_use': string = undefined;
}

export class QDTO_Specs extends SearchBase {
  constructor() {
    const like_prop = ['name'];
    const props = ['goods', 'name', 'is_use'];
    const mapping = [];
    super({ like_prop, props, mapping });
  }
  @ApiProperty({ description: '商品源' })
  'goods': string = undefined;
  @ApiProperty({ description: '规格名称' })
  'name': string = undefined;
  @ApiProperty({ description: '是否使用' })
  'is_use': string = undefined;
}

export class QVO_Specs extends FVO_Specs {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class CDTO_Specs {
  @ApiProperty({ description: '商品源' })
  @Rule(RuleType['string']().empty(''))
  'goods': string = undefined;
  @ApiProperty({ description: '规格名称' })
  @Rule(RuleType['string']().empty(''))
  'name': string = undefined;
  @ApiProperty({ description: '销售价格' })
  @Rule(RuleType['number']().empty(''))
  'money': number = undefined;
  @ApiProperty({ description: '库存' })
  @Rule(RuleType['number']().empty(''))
  'num': number = undefined;
  @ApiProperty({ description: '图片' })
  @Rule(RuleType['array']().empty(''))
  'file': Array<any> = undefined;
  @ApiProperty({ description: '是否使用' })
  @Rule(RuleType['string']().empty(''))
  'is_use': string = undefined;
}

export class CVO_Specs extends FVO_Specs {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}

export class UDTO_Specs extends CDTO_Specs {
  @ApiProperty({ description: '数据id' })
  @Rule(RuleType['string']().empty(''))
  _id: string = undefined;
}

export class UVAO_Specs extends FVO_Specs {
  constructor(data: object) {
    super(data);
    dealVO(this, data);
  }
}
