import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import {
  BaseService,
  FrameworkErrorEnum,
  ServiceError,
} from 'free-midway-component';
import { Cart } from '../entity/Cart.entity';
import { Good } from '../entity/Good.entity';
import { Specs } from '../entity/Specs.entity';
import { User } from '../entity/User.entity';
import { CDTO_Cart, QVO_Cart } from '../interface/Cart.interface';
import { Types } from 'mongoose';
import _ = require('lodash');
import { Office } from '../entity/Office.entity';
import { Order } from '../entity/Order.entity';
import { OrderDetail } from '../entity/OrderDetail.entity';
import { ShopSetting } from '../entity/ShopSetting.entity';
import { Collection } from '../entity/Collection.entity';
const assert = require('assert');
const moment = require('moment');
const ObjectId = Types.ObjectId;
type modelType = ReturnModelType<typeof Cart>;
@Provide()
export class CartService extends BaseService<modelType> {
  @InjectEntityModel(Cart)
  model: modelType;

  @InjectEntityModel(Good)
  goodModel: ReturnModelType<typeof Good>;

  @InjectEntityModel(Specs)
  specModel: ReturnModelType<typeof Specs>;

  @InjectEntityModel(User)
  userModel: ReturnModelType<typeof User>;

  @InjectEntityModel(Office)
  offModel: ReturnModelType<typeof Office>;

  @InjectEntityModel(Order)
  orderModel: ReturnModelType<typeof Order>;

  @InjectEntityModel(OrderDetail)
  orderDetailModel: ReturnModelType<typeof OrderDetail>;

  @InjectEntityModel(ShopSetting)
  shopModel: ReturnModelType<typeof ShopSetting>;

  @InjectEntityModel(Collection)
  collModel: ReturnModelType<typeof Collection>;

  // 特殊创建
  async specialCreate(data: CDTO_Cart): Promise<object> {
    const { user, supplier_id, goods, spec, num, total_money } = data;
    let res;
    // 查询库存 如果没有库存 不允许添加购物车小
    res = await this.specModel.findById(spec).lean();
    if (res.num <= 0) {
      throw new ServiceError(
        '商品库存不足 无法假如购物车',
        FrameworkErrorEnum.NOT_FOUND_DATA
      );
    }
    // 查询是否数据库中有相同数据
    const arr: any = await this.model
      .findOne({ user, supplier_id, goods, spec })
      .lean();
    if (arr) {
      // 如果有就修改这条数据
      data.num = arr.num + num;
      data.total_money = arr.total_money + total_money;
      res = await this.model.updateOne({ _id: new ObjectId(arr._id) }, data);
    } else res = await this.model.create(data);
    // 没有就创建
    return res;
  }

  // 查询购物车全部商品
  async self(user: string): Promise<Array<any>> {
    // 查询自己的购物车数据
    const data = await this.model.find({ user }).lean();
    // 商品重组 去重
    const uni = _.uniq(data.map(i => i.supplier_id));
    const result = [];
    for (const val of uni) {
      const list = data.filter(i => i.supplier_id === val);
      result.push(list);
    }
    const selfList: any = [];
    // 对重新按着厂商id组合的数组进行遍历 修改 id 变为具体数据
    for (const as of result) {
      const list: any = [];
      for (const val of as) {
        let res;
        const info: any = {};
        res = await this.goodModel.findById(val.goods).lean();
        info.goods = { _id: res._id, name: res.name, file: res.file };
        res = await this.specModel.findById(val.spec).lean();
        info.specs = {
          _id: res._id,
          name: res.name,
          money: res.money,
          num: res.num,
          file: res.file,
        };
        info.money = res.money;
        info.num = val.num;
        info.total_money = val.total_money;
        res = await this.userModel.findById(val.user).lean();
        info.user = { _id: res._id, name: res.name };
        info.cart_id = val._id;
        list.push(info);
      }
      const selfInfo: any = { list };
      const cs = await this.userModel.findById(as[0].supplier_id).lean();
      selfInfo.supplier = { _id: cs._id, name: cs.name };
      selfList.push(selfInfo);
    }
    return selfList;
  }
  // 购物车数量
  async num(user: string): Promise<number> {
    const data = await this.model.count({ user }).lean();
    return data;
  }
  // 结算
  async checkCartBuy(data) {
    assert(data.cartIds, '缺少选中商品信息');
    assert(data.totalMoney, '缺少总金额');
    const list = [];
    const obj: any = { status: '0' };
    // 查询选择的商品
    for (const val of data.cartIds) {
      const arr = await this.model.findById(val).lean();
      if (arr) list.push(arr);
    }
    let order;
    let Collection;
    let ShopSetting;
    if (list.length > 0) {
      // 创建订单数据
      const goods = [];
      for (const i of list) {
        const newData = new QVO_Cart(i);
        goods.push(newData);
      }
      obj.goods = goods;
      const result = await this.userModel.findById(list[0].user).lean();
      if (result) {
        let res;
        obj.user = result._id;
        if (result.street) {
          ShopSetting = await this.shopModel.findOne({
            office: result.street,
            is_use: '0',
          });
          Collection = await this.collModel.findOne({
            office: result.street,
            is_use: '0',
          });
          if (result.community) {
            res = await this.offModel.findById(result.community).lean();
          } else res = await this.offModel.findById(result.street).lean();
        } else assert(result.street, '缺少街道信息！');
        if (res.address) obj.address = res.address;
        else assert(res.address, '缺少收货地址信息！');
        if (ShopSetting) {
          obj.s_accounting = ShopSetting.accounting;
          obj.s_leader = ShopSetting.leader;
        } else obj.status = '4';
        if (Collection) {
          obj.c_accounting = Collection.accounting;
          obj.c_leader = Collection.leader;
        } else assert(Collection, '缺少回款审批信息！');
        obj.total_money = data.totalMoney;
        obj.buy_time = moment().format('YYYY-MM-DD HH:mm:ss');
        order = await this.orderModel.create(obj);
        for (const val of order.goods) {
          // 创建订单详情数据
          const info = {
            order_id: order._id,
            user: order.user,
            good: val.goods,
            spec: val.spec,
            supplier: val.supplier_id,
            address: order.address,
            num: val.num,
            money: val.money,
            total_money: val.total_money,
            s_accounting: order.s_accounting,
            s_leader: order.s_leader,
            c_accounting: order.c_accounting,
            c_leader: order.c_leader,
            buy_time: order.buy_time,
            status: order.status,
          };
          await this.orderDetailModel.create(info);
        }
        await this.checkGoodsNum(order);
      } else {
        throw new ServiceError(
          '未找到该用户',
          FrameworkErrorEnum.NOT_FOUND_DATA
        );
      }
    } else {
      throw new ServiceError(
        '未在购物车找到相关信息',
        FrameworkErrorEnum.NOT_FOUND_DATA
      );
    }
    // 删除购物车
    for (const val of data.cartIds) {
      await this.model.deleteOne({ _id: val }).lean();
    }
    return order;
  }

  // 部分删除购物车数据
  async deleteSome(data): Promise<string> {
    assert(data.cartIds, '缺少选中删除信息');
    // 删除购物车
    for (const val of data.cartIds) {
      await this.model.deleteOne({ _id: val }).lean();
    }
    return 'ok';
  }

  // 计算销量和库存量
  async checkGoodsNum(data) {
    let res;
    if (data) {
      for (const val of data.goods) {
        res = await this.specModel.findById(val.spec).lean();
        if (res) {
          const num = res.num - val.num;
          await this.specModel.updateOne({ _id: res._id }, { num }).lean();
        }
        res = await this.orderDetailModel.find({ good: val.goods }).lean();
        if (res) {
          let num = 0;
          for (const as of res) {
            num = num + as.num;
          }
          await this.goodModel
            .updateOne({ _id: val.goods }, { sell_num: num })
            .lean();
        }
      }
    }
  }
}
