import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { User } from '../entity/User.entity';
import { OrderDetail } from '../entity/OrderDetail.entity';
const moment = require('moment');
interface infoInterface {
  name: string;
  value: number;
}
@Provide()
export class StatisticsService {
  @InjectEntityModel(User)
  userModel: ReturnModelType<typeof User>;

  @InjectEntityModel(OrderDetail)
  orderDetailModel: ReturnModelType<typeof OrderDetail>;

  // 每个月下单数量
  async order(): Promise<Array<any>> {
    const result = [];
    const time = moment().format('YYYY');
    for (let i = 1; i < 13; i++) {
      let buy_time;
      if (i < 10) buy_time = `${time}-0${i}`;
      else buy_time = `${time}-${i}`;
      const info: infoInterface = { name: '', value: 0 };
      info.name = i + '月';
      info.value = await this.orderDetailModel
        .count({ buy_time: { $regex: buy_time } })
        .lean();
      result.push(info);
    }
    return result;
  }

  // 每个月下单数量
  async orderDetail(filter): Promise<Array<any>> {
    const { supplier, time, c_accounting, c_leader } = filter;
    const result = [];
    const search: any = { status: '10' };
    if (supplier) search.supplier = supplier;
    if (c_leader) search.c_leader = { $elemMatch: { _id: c_leader } };
    else if (c_accounting)
      search.c_accounting = { $elemMatch: { _id: c_accounting } };
    for (let i = 1; i < 13; i++) {
      let buy_time;
      if (i < 10) buy_time = `${time}-0${i}`;
      else buy_time = `${time}-${i}`;
      search.buy_time = { $regex: buy_time };
      const info: any = { year: '', money: 0 };
      info.year = i + '月';
      info.money = 0;
      const res = await this.orderDetailModel.find(search).lean();
      for (const val of res) {
        info.money = info.money + val.total_money;
      }
      result.push(info);
    }
    return result;
  }

  // 每个月注册数量
  async user(): Promise<Array<any>> {
    const result = [];
    const time = moment().format('YYYY');
    for (let i = 1; i < 13; i++) {
      let create_time;
      if (i < 10) create_time = `${time}-0${i}`;
      else create_time = `${time}-${i}`;
      result.push(
        await this.userModel
          .count({ create_time: { $regex: create_time } })
          .lean()
      );
    }
    return result;
  }
}
