import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import {
  BaseService,
  FrameworkErrorEnum,
  ServiceError,
} from 'free-midway-component';
import { User } from '../entity/User.entity';
import isEqual = require('lodash/isEqual');
import { LoginDTO } from '../interface/User.interface';
import { Office } from '../entity/Office.entity';
type modelType = ReturnModelType<typeof User>;
@Provide()
export class UserService extends BaseService<modelType> {
  @InjectEntityModel(User)
  model: modelType;

  @InjectEntityModel(Office)
  offModel: ReturnModelType<typeof Office>;

  async findUserToLogin(data: LoginDTO): Promise<object> {
    const { tel, password } = data;
    const user = await this.model.findOne({ tel }, '+password').lean();
    if (!user)
      throw new ServiceError(
        '未找到用户信息',
        FrameworkErrorEnum.NOT_FOUND_DATA
      );
    if (!isEqual(user.password.secret, password))
      throw new ServiceError('密码错误', FrameworkErrorEnum.SERVICE_FAULT);
    if (user.status === '0')
      throw new ServiceError(
        '账号审核中，请稍后再试',
        FrameworkErrorEnum.NOT_FOUND_DATA
      );
    if (user.status === '-1')
      throw new ServiceError(
        '账号审核拒绝 请重新申请！',
        FrameworkErrorEnum.NOT_FOUND_DATA
      );
    return user;
  }
  async wxLogin(openid: string): Promise<object> {
    const user = await this.model.findOne({ openid }).lean();
    if (!user)
      throw new ServiceError(
        '未找到用户信息',
        FrameworkErrorEnum.NOT_FOUND_DATA
      );
    if (user.status === '0')
      throw new ServiceError(
        '账号审核中，请稍后再试',
        FrameworkErrorEnum.NOT_FOUND_DATA
      );
    if (user.status === '-1')
      throw new ServiceError(
        '账号审核拒绝 请重新申请！',
        FrameworkErrorEnum.NOT_FOUND_DATA
      );
    return user;
  }
}
